@@ -16,10 +16,9 @@ def includeme(config):
     this keeps our routes from appearing in the debugtoolbar
     """
     config.registry.settings['debugtoolbar.extra_panels'].append(SqlalchemyCsvDebugPanel)
-    config.add_route('debugtoolbar.sqlalchemy_api_csv', '/api-sqlalchemy/sqlalchemy-{request_id}.csv')
+    config.add_route('debugtoolbar.api_sqlalchemy.queries.csv', '/api-sqlalchemy/sqlalchemy-{request_id}.csv')
     config.scan('pyramid_debugtoolbar_api_sqlalchemy.views')
     config.commit()
 
 
 # ==============================================================================
-
